//
//  Coffee.swift
//  DevelopersFuel
//
//  Created by Simone Figlie' on 24/08/20.
//  Copyright © 2020 Simone Figlie'. All rights reserved.
//

import Foundation

struct CoffeeType: Decodable, Identifiable {
    var id: UUID
    var name: String
    var coffees: [Coffee]
    
    enum CoffeTypeCodingKeys: String, CodingKey {
        case name
        case coffees
    }
    
    init(from decoder: Decoder) throws {
        let container = try decoder.container(keyedBy: CoffeTypeCodingKeys.self)
        self.name = try container.decode(String.self, forKey: .name)
        self.coffees = try container.decode([Coffee].self, forKey: .coffees)
        self.id = UUID()
    }
}

enum Size: String, Codable, Hashable  {
    case short = "Short (8 fl oz)"
    case tall = "Tall (12 fl oz)"
    case grande = "Grande (16 fl oz)"
    case venti = "Venti (20 fl oz)"
}

struct Coffee: Decodable, Identifiable {
    var id: UUID
    var name: String
    var description: String
    var photo: String
    var ingredients: [String]
    
    enum CoffeeCodingKeys: String, CodingKey {
        case name
        case description
        case photo
        case ingredients
    }
    
    init(from decoder: Decoder) throws {
        let container = try decoder.container(keyedBy: CoffeeCodingKeys.self)
        self.name = try container.decode(String.self, forKey: .name)
        self.description = try container.decode(String.self, forKey: .description)
        self.photo = try container.decode(String.self, forKey: .photo)
        self.ingredients = try container.decode([String].self, forKey: .ingredients)
        self.id = UUID()
    }
    
    init(id: UUID, name: String, description: String, photo: String, ingredients: [String]) {
        self.id = id
        self.name = name
        self.description = description
        self.photo = photo
        self.ingredients = ingredients
    }
    
    #if DEBUG
    static let coffeeExample = Coffee(id: UUID(), name: "Caffè Mocha", description: "Our rich, full-bodied espresso combined with bittersweet mocha sauce and steamed milk, then topped with sweetened whipped cream. The classic coffee drink that always sweetly satisfies.", photo: "Caffè mocha", ingredients: ["Milk", "Brewed Espresso", "Mocha Sauce","Whipped Cream"])
    #endif
}
